==> savane-1.2.tar.gz: savane-1.2/frontend/php/project/search.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: search.php,v 1.1 2005/09/27 13:16:03 yeupou Exp $
#
#  Copyright 2005 (c) Mathieu Roy <yeupou--gnu.org>
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

require "../include/pre.php";

site_project_header(array('group'=>$group_id,
			  'toptab'=>'searchingroup'));

# Ideally, we would like to do a real site wide search, which mean being able 
# to do a search without selecting a given tracker.
# To do that, we must run a SQL command per tracker, put everything in an 
# array. Fine, but the current function returns SQL results, and we wont 
# change that right now. So we ask the user to provide input.
# But it has to be kept in mind that we want this page to allow a search
# over all trackers, in the end.
print sprintf(_("With the following form, you can perform a search in the items summaries and details of a given tracker of the project %s. If you need to perform more complex search, use the query forms in Browse items page of this tracker. If you want to perform a site-wide search, use the search box in the left menu."), group_getname($group_id));
# use the string alltrackers to say we want a search to be performed over 
# all of them
print html_show_boxoptions($title, search_box('', '', 45));

site_project_footer(array());

?>

==> savane-1.3+2.tar.gz: savane-1.3+2/frontend/php/project/search.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: search.php 5187 2005-12-01 16:22:29Z yeupou $
#
#  Copyright 2005 (c) Mathieu Roy <yeupou--gnu.org>
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

require "../include/pre.php";

site_project_header(array('group'=>$group_id,
			  'context'=>'searchingroup'));


# Ideally, we would like to do a real site wide search, which mean being able 
# to do a search without selecting a given tracker.
# To do that, we must run a SQL command per tracker, put everything in an 
# array. Fine, but the current function returns SQL results, and we wont 
# change that right now. So we ask the user to provide input.
# But it has to be kept in mind that we want this page to allow a search
# over all trackers, in the end.
print sprintf(_("With the following form, you can perform a search in the items summaries and details of a given tracker of the project %s. If you need to perform more complex search, use the query forms in Browse items page of this tracker. If you want to perform a site-wide search, use the search box in the left menu."), group_getname($group_id));
# use the string alltrackers to say we want a search to be performed over 
# all of them
print html_show_boxoptions($title, search_box('', '', 45));

site_project_footer(array());

?>
